{% if not experiment.with_lucid_recruitment() %}
{% set BASE_PAYMENT = "%.2f"|format(participant.base_payment) %}
{% set TIME_REWARD = "%.2f"|format(participant.time_reward) %}
{% set PERFORMANCE_REWARD = "%.2f"|format(participant.performance_reward) %}
{% set CURRENCY = config.currency %}
{% trans name="final-page-rewards" %}You will receive a reward of <strong>{{ CURRENCY }}{{ TIME_REWARD }}</strong> for the time you spent on the experiment. You have also been awarded a performance reward of <strong>{{ CURRENCY }}{{ PERFORMANCE_REWARD }}</strong>!{% endtrans %}

{% if participant.performance_reward > 0.0 %}
    {% trans name="final-page-rewards" %}You have also been awarded a performance reward of <strong>{{ CURRENCY }}{{PERFORMANCE_REWARD}}</strong>!{% endtrans %}
{% endif %}
{% endif %}
